pub struct Build {
pub file: PathBuf,
pub out: Option<PathBuf>,
pub context: Option<PathBuf>,
pub no_pretty: Option<bool>,
}Fields
file: PathBufTarget path to render. If the target path is a directory, the root folder must contains the index.sql file
out: Option<PathBuf>Output path. The file will be overwritten if is already exists
context: Option<PathBuf>Change the context current working dir
no_pretty: Option<bool>No pretty print for SQL